######
Citing
######

If scipr is useful for your research, please consider citing our
`bioRxiv paper <https://www.biorxiv.org/content/10.1101/2020.05.13.093948v1>`_.

*******
Credits
*******

================
Development Lead
================

* Amir Alavi <amiralavi@cmu.edu>

============
Contributors
============

None yet. Why not be the first?
